<?php

namespace Bixo\Contractsform\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Contractsform\Forms\Deal as DealForm;
use Bixo\Contractsform\Http\Requests\DealResourceRequest;
use Bixo\Contractsform\Http\Resources\DealResource;
use Bixo\Contractsform\Http\Resources\DealsCollection;
use Bixo\Contractsform\Models\Deal;
use Bixo\Contractsform\Actions\DealAction;
use Bixo\Contractsform\Actions\DealActions;


/**
 * Resource controller class for deal.
 */
class DealResourceController extends BaseController
{

    /**
     * Initialize deal resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = DealForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.contractsform.modules'), 'contractsform', guard_url('contractsform'));
            return $next($request);
        });
    }

    /**
     * Display a list of deal.
     *
     * @return Response
     */
    public function index(DealResourceRequest $request)
    {
        $request = $request->all();
        $page = DealActions::run('paginate', $request);

        $data = new DealsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('contractsform::deal.names'))
            ->view('contractsform::deal.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display deal.
     *
     * @param Request $request
     * @param Model   $deal
     *
     * @return Response
     */
    public function show(DealResourceRequest $request, Deal $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new DealResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('contractsform::deal.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('contractsform::deal.show')
            ->output();
    }

    /**
     * Show the form for creating a new deal.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DealResourceRequest $request, Deal $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new DealResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('contractsform::deal.name'))
            ->view('contractsform::deal.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new deal.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DealResourceRequest $request, Deal $model)
    {
        try {
            $request = $request->all();
            $model = DealAction::run('store', $model, $request);
            $data = new DealResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('contractsform::deal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contractsform/deal/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/contractsform/deal'))
                ->redirect();
        }

    }

    /**
     * Show deal for editing.
     *
     * @param Request $request
     * @param Model   $deal
     *
     * @return Response
     */
    public function edit(DealResourceRequest $request, Deal $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new DealResource($model);
        // return view('contractsform::deal.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('contractsform::deal.name'))
            ->view('contractsform::deal.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the deal.
     *
     * @param Request $request
     * @param Model   $deal
     *
     * @return Response
     */
    public function update(DealResourceRequest $request, Deal $model)
    {
        try {
            $request = $request->all();
            $model = DealAction::run('update', $model, $request);
            $data = new DealResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contractsform::deal.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contractsform/deal/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contractsform/deal/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the deal.
     *
     * @param Model   $deal
     *
     * @return Response
     */
    public function destroy(DealResourceRequest $request, Deal $model)
    {
        try {

            $request = $request->all();
            $model = DealAction::run('destroy', $model, $request);
            $data = new DealResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('contractsform::deal.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contractsform/deal/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contractsform/deal/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
