<?php

namespace Bixo\Contractsform\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Contractsform\Events\QuotationAction as QuotationActionEvent;
use Bixo\Contractsform\Notifications\QuotationAction as QuotationActionNotification;
use Litepie\Actions\Concerns\AsAction;

class QuotationAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the QuotationActionEvent.
     *
     * @param   QuotationActionEvent  $event
     * @return mixed
     */
    public function handle(QuotationActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $quotation.
     *
     * @param   QuotationActionEvent  $event
     * @return void
     */
    public function create(QuotationActionEvent $event)
    {
        $client = $event->quotation->client;
        Notification::send($client, new QuotationActionNotification($event));
    }

    /**
     * Handle the QuotationActionEvent as a listener.
     *
     * @param   QuotationActionEvent  $event
     * @return mixed
     */
    public function asListener(QuotationActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   QuotationActionEvent  $event
     * @return bool
     */
    private function isAllowed(QuotationActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
