<?php

namespace Bixo\Contractsform\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Contractsform\Events\QuotationWorkflow as QuotationWorkflowEvent;
use Bixo\Contractsform\Notifications\QuotationWorkflow as QuotationWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class QuotationWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(QuotationWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $quotation is submitted.
     *
     * @param QuotationWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(QuotationWorkflowEvent $event)
    {
        $client = $event->quotation->client;
        Notification::send($client, new QuotationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $quotation is published.
     *
     * @param QuotationWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(QuotationWorkflowEvent $event)
    {
        $client = $event->quotation->client;
        Notification::send($client, new QuotationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $quotation is approved.
     *
     * @param QuotationWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(QuotationWorkflowEvent $event)
    {
        $client = $event->quotation->client;
        Notification::send($client, new QuotationWorkflowNotification($event));
    }

    /**
     * Handles the $quotation workflow event as a listener.
     *
     * @param QuotationWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(QuotationWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
