<?php

namespace Bixo\Contractsform\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Contractsform\Events\TenderAction as TenderActionEvent;
use Bixo\Contractsform\Notifications\TenderAction as TenderActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TenderAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TenderActionEvent.
     *
     * @param   TenderActionEvent  $event
     * @return mixed
     */
    public function handle(TenderActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $tender.
     *
     * @param   TenderActionEvent  $event
     * @return void
     */
    public function create(TenderActionEvent $event)
    {
        $client = $event->tender->client;
        Notification::send($client, new TenderActionNotification($event));
    }

    /**
     * Handle the TenderActionEvent as a listener.
     *
     * @param   TenderActionEvent  $event
     * @return mixed
     */
    public function asListener(TenderActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TenderActionEvent  $event
     * @return bool
     */
    private function isAllowed(TenderActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
