<?php

namespace Bixo\Contractsform\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Contractsform\Events\TenderWorkflow as TenderWorkflowEvent;
use Bixo\Contractsform\Notifications\TenderWorkflow as TenderWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class TenderWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(TenderWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $tender is submitted.
     *
     * @param TenderWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(TenderWorkflowEvent $event)
    {
        $client = $event->tender->client;
        Notification::send($client, new TenderWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $tender is published.
     *
     * @param TenderWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(TenderWorkflowEvent $event)
    {
        $client = $event->tender->client;
        Notification::send($client, new TenderWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $tender is approved.
     *
     * @param TenderWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(TenderWorkflowEvent $event)
    {
        $client = $event->tender->client;
        Notification::send($client, new TenderWorkflowNotification($event));
    }

    /**
     * Handles the $tender workflow event as a listener.
     *
     * @param TenderWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(TenderWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
