<?php

namespace Bixo\Contractsform\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Contractsform\Models\Certificate;

class CertificatePolicy
{


    /**
     * Determine if the given user can view the certificate.
     *
     * @param Authenticatable $user
     * @param Certificate $certificate
     *
     * @return bool
     */
    public function view(Authenticatable $user, Certificate $certificate)
    {
        if ($authUser->canDo('contractsform.certificate.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $certificate->is_owner;
    }

    /**
     * Determine if the given user can create a certificate.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contractsform.certificate.create');
    }

    /**
     * Determine if the given user can update the given certificate.
     *
     * @param Authenticatable $user
     * @param Certificate $certificate
     *
     * @return bool
     */
    public function update(Authenticatable $user, Certificate $certificate)
    {
        if ($user->canDo('contractsform.certificate.edit') && $user->isAdmin()) {
            return true;
        }

        return $certificate->is_owner;
    }

    /**
     * Determine if the given user can delete the given certificate.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Certificate $certificate)
    {
        return $certificate->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
