<?php

namespace Bixo\Contractsform\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Contractsform\Models\Quotation;

class QuotationPolicy
{


    /**
     * Determine if the given user can view the quotation.
     *
     * @param Authenticatable $user
     * @param Quotation $quotation
     *
     * @return bool
     */
    public function view(Authenticatable $user, Quotation $quotation)
    {
        if ($authUser->canDo('contractsform.quotation.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $quotation->is_owner;
    }

    /**
     * Determine if the given user can create a quotation.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contractsform.quotation.create');
    }

    /**
     * Determine if the given user can update the given quotation.
     *
     * @param Authenticatable $user
     * @param Quotation $quotation
     *
     * @return bool
     */
    public function update(Authenticatable $user, Quotation $quotation)
    {
        if ($user->canDo('contractsform.quotation.edit') && $user->isAdmin()) {
            return true;
        }

        return $quotation->is_owner;
    }

    /**
     * Determine if the given user can delete the given quotation.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Quotation $quotation)
    {
        return $quotation->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
