<?php

namespace Bixo\Contractsform\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Contractsform\Models\Tender;

class TenderPolicy
{


    /**
     * Determine if the given user can view the tender.
     *
     * @param Authenticatable $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function view(Authenticatable $user, Tender $tender)
    {
        if ($authUser->canDo('contractsform.tender.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $tender->is_owner;
    }

    /**
     * Determine if the given user can create a tender.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contractsform.tender.create');
    }

    /**
     * Determine if the given user can update the given tender.
     *
     * @param Authenticatable $user
     * @param Tender $tender
     *
     * @return bool
     */
    public function update(Authenticatable $user, Tender $tender)
    {
        if ($user->canDo('contractsform.tender.edit') && $user->isAdmin()) {
            return true;
        }

        return $tender->is_owner;
    }

    /**
     * Determine if the given user can delete the given tender.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Tender $tender)
    {
        return $tender->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
