<?php

namespace Bixo\Contractsform\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Bixo\Contractsform\Models\Tender;
use Bixo\Contractsform\Models\Contract;
use Bixo\Contractsform\Models\Deal;
use Bixo\Contractsform\Models\Quotation;
use Bixo\Contractsform\Models\Certificate;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Contractsform\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/contractsform/tender/*')) {
            Route::bind('tender', function ($tender) {
                return Tender::findorNew($tender);
            });
        }
        if (Request::is('*/contractsform/contract/*')) {
            Route::bind('contract', function ($contract) {
                return Contract::findorNew($contract);
            });
        }
        if (Request::is('*/contractsform/deal/*')) {
            Route::bind('deal', function ($deal) {
                return Deal::findorNew($deal);
            });
        }
        if (Request::is('*/contractsform/quotation/*')) {
            Route::bind('quotation', function ($quotation) {
                return Quotation::findorNew($quotation);
            });
        }
        if (Request::is('*/contractsform/certificate/*')) {
            Route::bind('certificate', function ($certificate) {
                return Certificate::findorNew($certificate);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
